package wekan.wrapper.api;

import retrofit2.Call;
import retrofit2.http.*;
import wekan.wrapper.entity.Comment;

import java.util.List;

public interface CardCommentService {

    /**
     * Get all comments attached to a card.
     *
     * @param boardId   The ID of the board
     * @param cardId    The ID of the card
     * @return  The list of the comments
     */
    @GET("/api/boards/{boardId}/cards/{cardId}/comments")
    Call<List<Comment>> getAllComments(
            @Path("boardId") String boardId,
            @Path("cardId") String cardId
    );

    /**
     * Post new comment attached on the give card.
     *
     * @param boardId   The ID of the board
     * @param cardId    The ID of the card
     * @param authorId  The ID of the author
     * @param comment   The comment
     * @return  The id of the new comment
     */
    @FormUrlEncoded
    @POST("/api/boards/{boardId}/cards/{cardId}/comments")
    Call<Comment> postNewComment(
            @Path("boardId") String boardId,
            @Path("cardId") String cardId,
            @Field("authorId") String authorId,
            @Field("comment") String comment
    );
}
